@@ -1,9 +1,9 @@
 import click
-from taxonerd import TaxoNERD
-from taxonerd.extractor import TextExtractor
 import sys
+import os
 import logging
 import logging.config
+from taxonerd import TaxoNERD
 
 
 @click.group()
@@ -32,6 +32,13 @@ def cli():
     help="Add abbreviation detector to the pipeline",
     is_flag=True,
 )
+@click.option(
+    "--with-sentence",
+    "-s",
+    type=bool,
+    help="Add sentence segmenter to the pipeline",
+    is_flag=True,
+)
 @click.option("--link-to", "-l", type=str, help="Add entity linker to the pipeline")
 @click.option(
     "--thresh",
@@ -43,11 +50,11 @@ def cli():
 @click.option("--verbose", "-v", type=bool, help="Verbose mode", is_flag=True)
 @click.argument("input_text", required=False)
 def ask(
-    # model,
     input_dir,
     output_dir,
     filename,
     with_abbrev,
+    with_sentence,
     link_to,
     thresh,
     prefer_gpu,
@@ -60,8 +67,6 @@ def ask(
     if verbose:
         logging.basicConfig(format="%(levelname)s:%(message)s", level=logging.INFO)
 
-    ext = TextExtractor(logger=logger)
-
     ner_model = (
         "en_ner_eco_biobert"
         if (focus_on and focus_on == "accuracy")
@@ -73,6 +78,7 @@ def ask(
     ner = TaxoNERD(
         model=ner_model,
         with_abbrev=with_abbrev,
+        with_sentence=with_sentence,
         with_linking=link_to,
         threshold=thresh,
         prefer_gpu=prefer_gpu,
@@ -80,15 +86,28 @@ def ask(
         logger=logger,
     )
 
+    if output_dir:
+        if not os.path.exists(output_dir):
+            os.makedirs(output_dir)
+
     if input_text:
-        df = ner.find_entities(input_text)
+        df = ner.find_in_text(input_text)
         df.to_csv(sys.stdout, sep="\t", header=False)
-    elif input_dir:
-        input_dir = ext(input_dir)
-        ner.find_all_files(input_dir, output_dir)
-    elif filename:
-        filename = ext(filename)
-        ner.find_in_file(filename, output_dir)
+    else:
+        dfs = {}
+        if filename:
+            dfs[os.path.basename(filename)] = ner.find_in_file(filename, output_dir)
+        elif input_dir:
+            dfs = ner.find_in_corpus(input_dir, output_dir)
+
+        if not output_dir:
+            if len(dfs) > 1:
+                for filename in dfs:
+                    dfs[filename] = dfs[filename].set_index(
+                        filename + "_" + dfs[filename].index.astype(str)
+                    )
+            for filename in dfs:
+                dfs[filename].to_csv(sys.stdout, sep="\t", header=False)
 
 
 def main():
