@@ -1,4 +1,5 @@
 from typing import List, Dict, Tuple, NamedTuple, Type
+from pathlib import Path
 import json
 import datetime
 from collections import defaultdict
@@ -74,9 +75,49 @@ TaxRefLinkerPaths = LinkerPaths(
     ),  # concept_aliases.json
 )
 
+NCBILinkerPaths = LinkerPaths(
+    ann_index=(
+        "https://cloud.univ-grenoble-alpes.fr/index.php/s/KFTJGLTaybAtXRr/download",
+        "ncbi_taxonomy/nmslib_index.bin",
+    ),  # nmslib_index.bin
+    tfidf_vectorizer=(
+        "https://cloud.univ-grenoble-alpes.fr/index.php/s/7J7PDeLm9nqDfSW/download",
+        "ncbi_taxonomy/tfidf_vectorizer.joblib",
+    ),  # tfidf_vectorizer.joblib
+    tfidf_vectors=(
+        "https://cloud.univ-grenoble-alpes.fr/index.php/s/qs4Z3spF9fXyxcD/download",
+        "ncbi_taxonomy/tfidf_vectors_sparse.npz",
+    ),  # tfidf_vectors_sparse.npz
+    concept_aliases_list=(
+        "https://cloud.univ-grenoble-alpes.fr/index.php/s/4qXgd8EoJRBFmbw/download",
+        "ncbi_taxonomy/concept_aliases.json",
+    ),  # concept_aliases.json
+)
+
+NCBILiteLinkerPaths = LinkerPaths(
+    ann_index=(
+        "https://cloud.univ-grenoble-alpes.fr/index.php/s/kB7AE44jy42qZec/download",
+        "/ncbi_taxonomy_lite/nmslib_index.bin",
+    ),  # nmslib_index.bin
+    tfidf_vectorizer=(
+        "https://cloud.univ-grenoble-alpes.fr/index.php/s/jLwQgt2eD7P3PDo/download",
+        "/ncbi_taxonomy_lite/tfidf_vectorizer.joblib",
+    ),  # tfidf_vectorizer.joblib
+    tfidf_vectors=(
+        "https://cloud.univ-grenoble-alpes.fr/index.php/s/enK6yZepTiGijgd/download",
+        "/ncbi_taxonomy_lite/tfidf_vectors_sparse.npz",
+    ),  # tfidf_vectors_sparse.npz
+    concept_aliases_list=(
+        "https://cloud.univ-grenoble-alpes.fr/index.php/s/LfjHkYcHAWK3kKS/download",
+        "ncbi_taxonomy_lite/concept_aliases.json",
+    ),  # concept_aliases.json
+)
+
 DEFAULT_PATHS: Dict[str, LinkerPaths] = {
     "gbif_backbone": GbifLinkerPaths,
     "taxref": TaxRefLinkerPaths,
+    "ncbi_taxonomy": NCBILinkerPaths,
+    "ncbi_lite": NCBILiteLinkerPaths,
 }
 
 
